@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -184,9 +184,15 @@ QJsonObject Configurator::CreateJsonSettingObject(const Configurator::LoaderSett
         json_layers.append(json_layer);
     }
 
-    if (!loader_settings.executable_path.empty()) {
+    // This new message is shown in SDK integration test
+    if (false && !loader_settings.executable_path.Exists()) {
+        this->Log(LOG_ERROR,
+                  format("Executable path not found: %s", loader_settings.executable_path.AbsolutePath().c_str()).c_str());
+    }
+
+    if (!loader_settings.executable_path.Empty()) {
         QJsonArray json_app_keys;
-        json_app_keys.append(loader_settings.executable_path.c_str());
+        json_app_keys.append(loader_settings.executable_path.AbsolutePath().c_str());
         json_settings.insert("app_keys", json_app_keys);
     }
 
@@ -825,7 +831,7 @@ std::string Configurator::Log() const {
     log += format(" - Vulkan Layers configuration scope: %s\n", ::GetLabel(this->GetExecutableScope()));
     log += format("   * Loader settings: %s\n", Path(Path::LOADER_SETTINGS).AbsolutePath().c_str());
 
-    if (this->GetExecutableScope() == EXECUTABLE_ANY || this->GetExecutableScope() == EXECUTABLE_ALL) {
+    if (this->GetExecutableScope() == EXECUTABLE_ANY) {
         log += format("   * Layers settings: %s\n", Path(Path::LAYERS_SETTINGS).AbsolutePath().c_str());
     }
 
@@ -837,6 +843,7 @@ std::string Configurator::Log() const {
             log += " - No Active Vulkan Loader Configuration\n";
         }
     }
+    /*
     if (this->GetExecutableScope() == EXECUTABLE_ALL) {
         log += " - Listed Executables:\n";
         const std::vector<Executable>& executables = this->executables.GetExecutables();
@@ -845,15 +852,22 @@ std::string Configurator::Log() const {
                           executables[i].enabled ? "enabled" : "disabled");
         }
     }
+    */
 
-    if (this->GetExecutableScope() == EXECUTABLE_PER) {
+    if (this->GetExecutableScope() == EXECUTABLE_PER || this->GetExecutableScope() == EXECUTABLE_ALL) {
         log += " - Listed Executables:\n";
         const std::vector<Executable>& executables = this->executables.GetExecutables();
         for (std::size_t i = 0, n = executables.size(); i < n; ++i) {
-            const Configuration* configuration = this->configurations.FindConfiguration(executables[i].configuration);
+            if (this->GetExecutableScope() == EXECUTABLE_PER) {
+                const Configuration* configuration = this->configurations.FindConfiguration(executables[i].configuration);
+
+                log += format("   * %s: '%s'\n", executables[i].path.AbsolutePath().c_str(),
+                              executables[i].enabled && configuration != nullptr ? executables[i].configuration.c_str() : "None");
+            } else {
+                log += format("   * %s: %s\n", executables[i].path.AbsolutePath().c_str(),
+                              executables[i].enabled ? "enabled" : "disabled");
+            }
 
-            log += format("   * %s: '%s'\n", executables[i].path.AbsolutePath().c_str(),
-                          executables[i].enabled && configuration != nullptr ? executables[i].configuration.c_str() : "None");
             if (!executables[i].enabled) {
                 continue;
             }
@@ -1206,6 +1220,11 @@ bool Configurator::Load() {
             if (json_object.value("VULKAN_HOME") != QJsonValue::Undefined) {
                 ::SetHomePath(json_object.value("VULKAN_HOME").toString().toStdString());
             }
+
+            if (json_object.value("all_enabled_executables_behavior") != QJsonValue::Undefined) {
+                this->executable_behavior = ::GetExecutableAllEnabledBehavior(
+                    json_object.value("all_enabled_executables_behavior").toString().toStdString().c_str());
+            }
             if (json_object.value("VULKAN_DOWNLOAD") != QJsonValue::Undefined) {
                 ::SetDownloadPath(json_object.value("VULKAN_DOWNLOAD").toString().toStdString());
             }
@@ -1346,6 +1365,8 @@ bool Configurator::Save() const {
         json_object.insert("show_external_layers_settings", this->show_external_layers_settings);
         json_object.insert("VULKAN_HOME", ::Path(Path::HOME).RelativePath().c_str());
         json_object.insert("VULKAN_DOWNLOAD", ::Path(Path::DOWNLOAD).RelativePath().c_str());
+        json_object.insert("all_enabled_executables_behavior", ::GetToken(this->executable_behavior));
+
         json_interface_object.insert(GetToken(TAB_PREFERENCES), json_object);
     }
 
@@ -1408,6 +1429,10 @@ bool Configurator::GetUseSystemTray() const { return this->use_system_tray; }
 
 void Configurator::SetUseSystemTray(bool enabled) { this->use_system_tray = enabled; }
 
+ExecutableAllEnabledBehavior Configurator::GetAllEnabledExecutableBehavior() const { return this->executable_behavior; }
+
+void Configurator::SetAllEnabledExecutableBehavior(ExecutableAllEnabledBehavior behavior) { this->executable_behavior = behavior; }
+
 bool Configurator::GetUseLayerDebugMode() const { return this->use_layer_debug_mode; }
 
 void Configurator::SetUseLayerDebugMode(bool enabled) { this->use_layer_debug_mode = enabled; }
